@@ -3,29 +3,20 @@ package options
 import (
 	"fmt"
 
-	"github.com/spf13/pflag"
-	"github.com/spf13/viper"
+	"github.com/anchore/fangs"
 )
 
-var _ Interface = &Format{}
+var _ fangs.FlagAdder = (*Format)(nil)
 
 type Format struct {
 	Output           string   `yaml:"output" json:"output" mapstructure:"output"`
 	AllowableFormats []string `yaml:"-" json:"-" mapstructure:"-"`
 }
 
-func (o *Format) Redact() {
-
-}
-
-func (o *Format) AddFlags(flags *pflag.FlagSet) {
+func (o *Format) AddFlags(flags fangs.FlagSet) {
 	flags.StringVarP(
 		&o.Output,
-		"output", "o", o.Output,
+		"output", "o",
 		fmt.Sprintf("output format to report results in (allowable values: %s)", o.AllowableFormats),
 	)
 }
-
-func (o *Format) BindFlags(flags *pflag.FlagSet, v *viper.Viper) error {
-	return Bind(v, "output", flags.Lookup("output"))
-}
